@@ -16,38 +16,46 @@
 
 # Embedded icon is designed by Igor Kekeljevic (http://www.admiror-ns.co.yu).
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #--- PIL function
+
+
 def init():
     #lazy import
     global Image, ImageChops, imtools
-    import Image, ImageChops
+    import Image
+    import ImageChops
     from lib import imtools
 
+
 def invert(image, amount=100):
     image = imtools.convert_safe_mode(image)
     inverted = ImageChops.invert(image)
     if amount < 100:
-        inverted  = imtools.blend(image, inverted, amount/100.0)
+        inverted = imtools.blend(image, inverted, amount / 100.0)
     if imtools.has_alpha(image):
-        inverted.putalpha(image.split()[-1])
+        inverted.putalpha(imtools.get_alpha(image))
     return inverted
 
 #--- Phatch Action
-class Action(models.Action):
-    label       = _t('Invert')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(invert)
-    version     = '0.1'
-    tags        = [_t('color')]
-    __doc__     = _t('Invert the colors of an image')
 
-    def interface(self,fields):
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+
+class Action(models.Action):
+    label = _t('Invert')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(invert)
+    version = '0.1'
+    tags = [_t('color')]
+    __doc__ = _t('Invert the colors of an image')
+
+    def interface(self, fields):
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01\x91\nn\xf5\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
