@@ -18,37 +18,46 @@
 
 # Embedded icon is taken from www.openclipart.org (public domain)
 
+# Follows PEP8
+
 from core import models
 from lib.reverse_translation import _t
 
 #---PIL
+
+
 def init():
     global Image, ImageFilter, imtools
-    import Image, ImageFilter
+    import Image
+    import ImageFilter
     from lib import imtools
 
-def maximum(image,radius,amount=100):
+
+def maximum(image, radius, amount=100):
     """Apply a filter
     - amount: 0-1"""
-    maximumed  = image.filter(ImageFilter.MaxFilter(radius))
+    image = imtools.convert_safe_mode(image)
+    maximumed = image.filter(ImageFilter.MaxFilter(radius))
     if amount < 100:
-        return imtools.blend(image, maximumed, amount/100.0)
+        return imtools.blend(image, maximumed, amount / 100.0)
     return maximumed
 
 #---Phatch
-class Action(models.Action):
-    label       = _t('Maximum')
-    author      = 'Stani'
-    email       = 'spe.stani.be@gmail.com'
-    init        = staticmethod(init)
-    pil         = staticmethod(maximum)
-    version     = '0.1'
-    tags        = [_t('filter')]
-    __doc__     = _t("Copies the maximum pixel value")
 
-    def interface(self,fields):
+
+class Action(models.Action):
+    label = _t('Maximum')
+    author = 'Stani'
+    email = 'spe.stani.be@gmail.com'
+    init = staticmethod(init)
+    pil = staticmethod(maximum)
+    version = '0.1'
+    tags = [_t('filter')]
+    __doc__ = _t("Copies the maximum pixel value")
+
+    def interface(self, fields):
         fields[_t('Radius')] = self.RankSizeField(self.RANK_SIZES[0])
-        fields[_t('Amount')] = self.SliderField(100,1,100)
+        fields[_t('Amount')] = self.SliderField(100, 1, 100)
 
     icon = \
 'x\xda\x01\xba\x08E\xf7\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x000\x00\
