@@ -71,7 +71,6 @@ from lib.pyWx import graphics
 from lib.pyWx import imageFileBrowser
 from lib.pyWx import imageInspector
 from lib.pyWx import paint
-from lib.pyWx.compatible import GCDC, FONT_SIZE
 from lib.pyWx.clipboard import copy_text
 
 import images
@@ -84,7 +83,7 @@ COMMAND_PASTE = \
     _('You can paste it as text into the properties of a new launcher.')
 ERROR_INSTALL_ACTION = \
 _('Sorry, you need to install the %s action for this action list.')
-WARNING_LOST_VALUES=\
+WARNING_LOST_VALUES = \
 _('Sorry, the values of these options will be lost in %(name)s %(version)s:')
 CLIPBOARD_ACTIONLIST = \
 _('The droplet command for this action list was copied to the clipboard.')
@@ -93,14 +92,15 @@ _('The droplet command for recent action lists was copied to the clipboard.')
 CLIPBOARD_IMAGE_INSPECTOR = \
 _('The droplet command for the image inspector was copied to the clipboard.')
 NO_PHOTOS = \
-_('In Phatch you need to open or create an action list first.')+' '+\
-_('As an example try out the polaroid action list from the library.')+\
-'\n'+\
-_('Afterwards you can drag&drop images on the Phatch window to batch them.')+\
-'\n\n'+\
+_('In Phatch you need to open or create an action list first.') + ' ' + \
+_('As an example try out the polaroid action list from the library.') + \
+'\n' + \
+_('Afterwards you can drag&drop images on the Phatch window to batch them.') +\
+'\n\n' + \
 _('For more information see the tutorials (Help>Documentation)')
 #---theme
 
+
 def _theme():
     if wx.Platform != '__WXGTK__':
         set_theme('nuovext')
@@ -113,6 +113,7 @@ def set_theme(name='default'):
 
 #---Functions
 
+
 def findWindowById(id):
     return wx.GetApp().GetTopWindow().FindWindowById(id)
 
@@ -122,7 +123,7 @@ class DialogsMixin:
 
     #---dialogs
     def show_error(self, message):
-        return self.show_message(message, style=wx.OK|wx.ICON_ERROR)
+        return self.show_message(message, style=wx.OK | wx.ICON_ERROR)
 
     def show_execute_dialog(self, result, settings, files=None):
         dlg = dialogs.ExecuteDialog(self, drop=files)
@@ -149,14 +150,15 @@ class DialogsMixin:
         dlg.SetSize((x, y))
         result['cancel'] = dlg.ShowModal() == wx.ID_CANCEL
 
-    def show_message(self, message, title='', style=wx.OK|wx.ICON_EXCLAMATION):
+    def show_message(self, message, title='',
+            style=wx.OK | wx.ICON_EXCLAMATION):
         if self.IsShown():
             parent = self
         else:
             parent = None
         dlg = wx.MessageDialog(parent,
                 message,
-                '%(name)s '%ct.INFO +title,
+                '%(name)s ' % ct.INFO + title,
                 style,
         )
         answer = dlg.ShowModal()
@@ -170,11 +172,11 @@ class DialogsMixin:
         dlg.ShowModal()
         dlg.Destroy()
 
-    def show_question(self, message, style=wx.YES_NO|wx.ICON_QUESTION):
+    def show_question(self, message, style=wx.YES_NO | wx.ICON_QUESTION):
         return self.show_message(message, style=style)
 
     def show_image_tree(self, result, image_infos, widths, headers,
-            ok_label = '&OK', buttons=False, modal=False):
+            ok_label='&OK', buttons=False, modal=False):
         data = listData.files_data_dict(image_infos)
         dlg = dialogs.ImageTreeDialog(data, listData.DataDict, headers,
             self, size=(600, dialogs.get_max_height(300)))
@@ -208,18 +210,19 @@ class DialogsMixin:
                 msg = _('Hooray, no issues!')
         else:
             msg = _('Nothing has been logged yet.')
-        self.show_scrolled_message(msg, '%s - %s'%(_('Log'), ct.USER_LOG_PATH))
+        self.show_scrolled_message(msg, '%s - %s' \
+            % (_('Log'), ct.USER_LOG_PATH))
 
     def show_info(self, message, title=''):
         return self.show_message(message, title,
-            style=wx.OK|wx.ICON_INFORMATION)
+            style=wx.OK | wx.ICON_INFORMATION)
 
     def show_progress(self, title, parent_max, child_max=1, message=''):
         dlg = dialogs.ProgressDialog(self, title, parent_max, child_max,
             message)
 
     def show_progress_error(self, result, message, ignore=True):
-        message += '\n\n'+api.SEE_LOG
+        message += '\n\n' + api.SEE_LOG
         errorDlg = dialogs.ErrorDialog(self, message, ignore)
         answer = errorDlg.ShowModal()
         result['stop_for_errors'] = not errorDlg.future_errors.GetValue()
@@ -235,7 +238,7 @@ class DialogsMixin:
     def show_scrolled_message(self, message, title, **keyw):
         import wx.lib.dialogs
         dlg = wx.lib.dialogs.ScrolledMessageDialog(self, message, title,
-            style=wx.DEFAULT_DIALOG_STYLE|wx.MAXIMIZE_BOX|wx.RESIZE_BORDER,
+            style=wx.DEFAULT_DIALOG_STYLE | wx.MAXIMIZE_BOX | wx.RESIZE_BORDER,
             **keyw)
         dlg.ShowModal()
 
@@ -244,10 +247,10 @@ class DialogsMixin:
         active = wx.GetApp().IsActive() or self.IsActive()
         if force or not active:
             notify.send(
-                title = system.filename_to_title(self.filename),
-                message = message,
-                icon = self.get_icon_filename(),
-                wxicon = graphics.bitmap(images.ICON_PHATCH_64))
+                title=system.filename_to_title(self.filename),
+                message=message,
+                icon=self.get_icon_filename(),
+                wxicon=graphics.bitmap(images.ICON_PHATCH_64))
         if not active:
             self.RequestUserAttention()
 
@@ -266,25 +269,25 @@ class DialogsMixin:
             data, warnings = api.open_actionlist(filename)
         except KeyError, details:
             self.show_error(ERROR_INSTALL_ACTION\
-                %exception_to_unicode(details, WX_ENCODING))
+                % exception_to_unicode(details, WX_ENCODING))
             return
         except:
-            self.show_error(api.ERROR_INCOMPATIBLE_ACTIONLIST%ct.INFO)
+            self.show_error(api.ERROR_INCOMPATIBLE_ACTIONLIST % ct.INFO)
             return
         if data['invalid labels']:
             self.show_message('\n'.join([
             _('This action list was made by a different %(name)s version.')\
-                %ct.INFO+'\n\n'+\
-            WARNING_LOST_VALUES%ct.INFO+'\n',
+                % ct.INFO + '\n\n' + \
+            WARNING_LOST_VALUES % ct.INFO + '\n',
             '\n'.join(data['invalid labels'])]))
         if warnings:
             if formField.get_safe():
-                self.show_error('%s\n\n%s\n%s'%(
+                self.show_error('%s\n\n%s\n%s' % (
                     api.ERROR_UNSAFE_ACTIONLIST_INTRO, warnings,
                     api.ERROR_UNSAFE_ACTIONLIST_DISABLE_SAFE))
                 return
             else:
-                wx.CallAfter(self.show_error, '%s\n\n%s\n%s'%(
+                wx.CallAfter(self.show_error, '%s\n\n%s\n%s' % (
                     api.ERROR_UNSAFE_ACTIONLIST_INTRO, warnings,
                     api.ERROR_UNSAFE_ACTIONLIST_ACCEPT))
         return data
@@ -323,7 +326,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
     def __init__(self, actionlist, *args, **keyw):
         frame.Frame.__init__(self, *args, **keyw)
         _theme()
-        self.dlg_library=None
+        self.dlg_library = None
         self.dirty = False
         self.EnableBackgroundPainting(self.empty)
         self._menu()
@@ -361,7 +364,6 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         self.menu_file_export = \
             self.menu_file_export_actionlist_to_clipboard.GetMenu()
         #file history
-        self.menu_file.AppendSeparator()
         self.menu_file_recent = wx.Menu()
         self.filehistory = wx.FileHistory()
         self.filehistory.UseMenu(self.menu_file_recent)
@@ -383,7 +385,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         #    id = wx.NewId()
         #    label = actionlist[0]
         #    if prefix:
-        #        label = '&%d %s'%(index+1, label)
+        #        label = '&%d %s' % (index + 1, label)
         #    item = library.Append(id, label)
         #    self.library_files[id] = actionlist[1]
         #    self.Bind(wx.EVT_MENU, self.on_menu_file_library, item)
@@ -392,9 +394,9 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         #self.menu_file.InsertMenu(3, wx_ID_EDIT, _("Open &Library"),
         #   library, "")
         self.library_files_dictionary = formField.files_dictionary(
-                    paths = [config.PATHS["PHATCH_ACTIONLISTS_PATH"],
+                    paths=[config.PATHS["PHATCH_ACTIONLISTS_PATH"],
                     ct.USER_ACTIONLISTS_PATH],
-                    extensions = ['png'])
+                    extensions=['png'])
 
         #shell
         self.shell = None
@@ -426,10 +428,13 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
             app.SetMacAboutMenuItemId(wx.ID_ABOUT)
             app.SetMacExitMenuItemId(wx.ID_EXIT)
             #app.SetMacPreferencesMenuItemId(wx.ID_PREFERENCES)
+        else:
+            self.menu_file.InsertSeparator(8)
+
     def _title(self):
         path, filename = os.path.split(self.filename)
         self.SetTitle(ct.FRAME_TITLE\
-            %(self.dirty, os.path.splitext(filename)[0]))
+            % (self.dirty, os.path.splitext(filename)[0]))
         self.frame_statusbar.SetStatusText(path)
         self.SetStatusText(ct.COPYRIGHT)
 
@@ -510,7 +515,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
             self.frame_toolbar.EnableTool(tool, state)
 
     def show_paint_message(self, message=None):
-        if message==None:
+        if message == None:
             self.paint_message = self.DEFAULT_PAINT_MESSAGE
         else:
             self.paint_message = message
@@ -531,11 +536,11 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
             return
         if not self.dlg_library:
             self.dlg_library = imageFileBrowser.Dialog(
-                parent = self,
-                files = self.library_files_dictionary,
-                title = _('Library Action Lists'),
-                size = (self.GetSize()[0], 370),
-                icon_size = (128, 128))
+                parent=self,
+                files=self.library_files_dictionary,
+                title=_('Library Action Lists'),
+                size=(self.GetSize()[0], 370),
+                icon_size=(128, 128))
             self.dlg_library.image_list.Select(0)
         if self.dlg_library.ShowModal() == wx.ID_OK:
             filename = self.dlg_library.image_path.GetValue()
@@ -552,10 +557,10 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         if self.is_save_not_ok():
             return
         dlg = wx.FileDialog(self,
-            message = _('Choose an Action List File...'),
-            defaultDir = os.path.dirname(self.filename),
-            wildcard = ct.WILDCARD,
-            style = wx.OPEN,
+            message=_('Choose an Action List File...'),
+            defaultDir=os.path.dirname(self.filename),
+            wildcard=ct.WILDCARD,
+            style=wx.OPEN,
         )
         if dlg.ShowModal() == wx.ID_OK:
             filename = dlg.GetPath()
@@ -584,19 +589,19 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         else:
             default_dir = os.path.dirname(self.filename)
         dlg = wx.FileDialog(self,
-            message = _('Save Action List As...'),
-            defaultDir = default_dir,
-            wildcard = ct.WILDCARD,
-            style = wx.SAVE|wx.OVERWRITE_PROMPT,
+            message=_('Save Action List As...'),
+            defaultDir=default_dir,
+            wildcard=ct.WILDCARD,
+            style=wx.SAVE | wx.OVERWRITE_PROMPT,
         )
         if dlg.ShowModal() == wx.ID_OK:
             saved = True
             path = dlg.GetPath()
-            if dlg.GetFilterIndex()==0 \
+            if dlg.GetFilterIndex() == 0 \
                     and not os.path.splitext(path)[1]:
                 path += ct.EXTENSION
                 if os.path.exists(path) and self.show_question('%s %s'\
-                        %(_('This file exists already.'),
+                        % (_('This file exists already.'),
                         _('Do you want to overwrite it?'))) == wx.ID_NO:
                     saved = False
             if saved:
@@ -609,7 +614,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
     def on_menu_file_export_actionlist_to_clipboard(self, event):
         if self.is_save_not_ok():
             return
-        copy_text(ct.COMMAND['DROP']%self.filename)
+        copy_text(ct.COMMAND['DROP'] % self.filename)
         self.show_info(' '.join([CLIPBOARD_ACTIONLIST, COMMAND_PASTE]))
 
     def on_menu_file_export_recent_to_clipboard(self, event):
@@ -641,8 +646,8 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         if not hasattr(self, 'dialog_actions'):
             self.dialog_actions = dialogs.ActionDialog(self,
                 api.ACTIONS, settings['tag_actions'],
-                size = (self._width, min(400, self._max_height)),
-                title = _("%(name)s actions")%ct.INFO)
+                size=(self._width, min(400, self._max_height)),
+                title=_("%(name)s actions") % ct.INFO)
         if self.dialog_actions.ShowModal() == wx.ID_OK:
             self.set_dirty(True)
             label = self.dialog_actions.GetStringSelection()
@@ -677,7 +682,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
 
     def droplet_label_format(self, x):
         #return '123456789012345678901234567890'
-        return x#[:18]
+        return x  # [:18]
 
     def on_menu_view_description(self, event):
         self.show_description(event.IsChecked())
@@ -700,8 +705,8 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
 
     def on_menu_tools_image_inspector(self, event):
         frame = dialogs.ImageInspectorFrame(self,
-            size = (470, dialogs.get_max_height(510)),
-            icon = images.get_icon('inspector'))
+            size=(470, dialogs.get_max_height(510)),
+            icon=images.get_icon('inspector'))
         frame.Show()
 
     def on_menu_tools_browse_library_user(self, event):
@@ -725,18 +730,18 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         if self.shell is None:
             title = ct.TITLE.lower()
             self.shell = shell.Frame(self,
-                title = _('%(name)s Shell')%ct.INFO,
-                intro = '%(name)s '%ct.INFO,
-                values = {
-                    '%s_%s'%(title, _('application')): wx.GetApp(),
-                    '%s_%s'%(title, _('frame')): self,
-                    '%s_%s'%(title, _('actions')): self.tree.export_forms,
+                title=_('%(name)s Shell') % ct.INFO,
+                intro='%(name)s ' % ct.INFO,
+                values={
+                    '%s_%s' % (title, _('application')): wx.GetApp(),
+                    '%s_%s' % (title, _('frame')): self,
+                    '%s_%s' % (title, _('actions')): self.tree.export_forms,
                     },
-                icon = self.icon,
+                icon=graphics.bitmap(images.ICON_PHATCH_64),
             )
         self.shell.Show(event.IsChecked())
 
-    def on_menu_help_website(self, event): # wxGlade: Frame.<event_handler>
+    def on_menu_help_website(self, event):
         webbrowser.open('http://photobatch.stani.be')
 
     def on_menu_help_documentation(self, event):
@@ -756,30 +761,36 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         help_path = self.get_setting("PHATCH_DOCS_PATH")
         help_file = os.path.join(help_path, 'index.html')
         if not os.path.exists(help_file):
+            #debian/ubuntu
             help_file = os.path.join(help_path, 'build', 'html',
                 'index.html')
+        if not os.path.exists(help_file):
+            #ppa
+            help_file = os.path.join(sys.prefix, 'share', 'phatch', 'docs',
+                'index.html')
         webbrowser.open(help_file)
         dlg = dialogs.WritePluginDialog(self, '\n'.join([
             _('A html tutorial will open in your internet browser.'),
             '',
             _('You only need to know PIL to write a plugin for Phatch.'),
             _('Phatch will generate the user interface automatically.'),
-            _('Study the action plugins in:')+' '+ct.PHATCH_ACTIONS_PATH,
+            _('Study the action plugins in:') + ' ' + ct.PHATCH_ACTIONS_PATH,
             '',
             _('If you want to contribute a plugin for Phatch,'),
-            _('please email: ')+ct.CONTACT]))
+            _('please email: ') + ct.CONTACT]))
         dlg.ShowModal()
         #settings in mixin because now app bas, also config_path
+
     def on_menu_help_about(self, event):
         from lib.pyWx import about
         from data.info import all_credits
         dlg = about.Dialog(self,
-            title = '%(version)s'%ct.INFO,
-            logo = graphics.bitmap(images.LOGO),
-            description = _('PHoto bATCH Processor & Renamer'),
-            website = ct.INFO['url'],
-            credits = all_credits(),
-            license = ct.LICENSE,
+            title='%(version)s' % ct.INFO,
+            logo=graphics.bitmap(images.LOGO),
+            description=_('PHoto bATCH Processor'),
+            website=ct.INFO['url'],
+            credits=all_credits(),
+            license=ct.LICENSE,
         )
         dlg.ShowModal()
         dlg.Destroy()
@@ -859,18 +870,18 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
             if api.check_actionlist(self.tree.export_forms(),
                     wx.GetApp().settings):
                 self.droplet = droplet.Frame(self,
-                    title = _("Drag & Drop")+' - '+ct.TITLE,
-                    bitmap = graphics.bitmap(images.DROPLET),
-                    method = self.on_drop,
-                    label = self.droplet_label_format(
+                    title=_("Drag & Drop") + ' - ' + ct.TITLE,
+                    bitmap=graphics.bitmap(images.DROPLET),
+                    method=self.on_drop,
+                    label=self.droplet_label_format(
                         system.filename_to_title(self.filename)),
-                    label_color = wx.Colour(217, 255, 186),
-                    label_pos = (8, 8),
-                    label_angle = 0,
-                    pos = self.GetPosition(),
-                    auto = True,
-                    OnShow = self.on_show_droplet,
-                    tooltip = _(
+                    label_color=wx.Colour(217, 255, 186),
+                    label_pos=(8, 8),
+                    label_angle=0,
+                    pos=self.GetPosition(),
+                    auto=True,
+                    OnShow=self.on_show_droplet,
+                    tooltip=_(
                     "Drop any files and/or folders on this Phatch droplet\n"
                     "to batch process them.\n"
                     "Right-click or double-click to switch to normal view."))
@@ -883,15 +894,15 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
     def on_show_droplet(self, bool):
         self.menu_view.Check(self.menu_view_droplet.GetId(), bool)
         if not bool:
-            self.droplet = None #don't keep a reference
+            self.droplet = None  # don't keep a reference
 
     #---checks
     def append_save_action(self, actions):
         only_metadata = self.only_actions_with_tag(actions, 'metadata')
-        message = ct.SAVE_ACTION_NEEDED+" "+\
+        message = ct.SAVE_ACTION_NEEDED + " " + \
             _("Phatch will add one for you, please check its settings.")
         if only_metadata:
-            message += ' \n\n%s%s'%(\
+            message += ' \n\n%s%s' % (\
             _('The action list only processes metadata.'),
             _('Phatch chooses the lossless "Save Tags" action.'))
         self.show_message(message)
@@ -918,7 +929,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         self.tree.Bind(wx.EVT_CONTEXT_MENU, self.on_context_menu, self.tree)
 
     def on_description_text(self, event):
-        if not self.dirty and event.GetString()!=self.saved_description:
+        if not self.dirty and event.GetString() != self.saved_description:
             self.set_dirty(True)
 
     def on_drop(self, filenames, x, y):
@@ -939,9 +950,9 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
 
     def is_save_not_ok(self):
         if self.dirty:
-            answer = self.show_message(_('Save last changes to')+'\n"%s"?'\
-                %self.filename,
-                style=wx.YES_NO|wx.CANCEL|wx.ICON_EXCLAMATION)
+            answer = self.show_message(_('Save last changes to') + '\n"%s"?'\
+                % self.filename,
+                style=wx.YES_NO | wx.CANCEL | wx.ICON_EXCLAMATION)
             if answer == wx.ID_CANCEL:
                 return True
             if answer == wx.ID_YES:
@@ -991,7 +1002,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
             answer = self.show_question(
                 _('Safe mode protects you from the execution of possibly '\
                 'harmful scripts.\nAre you sure you want to disable it?'),
-                style=wx.YES_NO|wx.ICON_QUESTION|wx.NO_DEFAULT)
+                style=wx.YES_NO | wx.ICON_QUESTION | wx.NO_DEFAULT)
             if answer != wx.ID_YES:
                 self.menu_tools.Check(self.menu_tools_safe.GetId(), True)
                 return
@@ -1000,7 +1011,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
     #---droplet
     def get_droplet_folder(self):
         folder = self.show_dir_dialog(
-            defaultPath = self.get_setting('droplet_path'),
+            defaultPath=self.get_setting('droplet_path'),
             message=_('Choose the folder for the droplet'))
         if folder:
             self.set_setting('droplet_path', folder)
@@ -1016,7 +1027,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         except Exception, details:
             reason = exception_to_unicode(details, WX_ENCODING)
             self.show_error(_('Phatch could not create the droplet: ')\
-                +'\n\n'+reason)
+                + '\n\n' + reason)
 
     def install_menu_item(self, menu, name, label, method, tooltip="",
             style=wx.ITEM_NORMAL):
@@ -1025,7 +1036,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
         setattr(self, name, item)
         menu.InsertItem(0, item)
         #method
-        method_name = 'on_'+name
+        method_name = 'on_' + name
         method = new.instancemethod(method, self, self.__class__)
         setattr(self, method_name, method)
         #bind item & method
@@ -1035,6 +1046,7 @@ class Frame(DialogsMixin, dialogs.BrowseMixin, droplet.Mixin, paint.Mixin,
 
 #---Image Inspector
 
+
 class ImageInspectorApp(wx.App):
 
     def __init__(self, paths, *args, **keyw):
@@ -1059,6 +1071,7 @@ def inspect(paths):
 
 #---Droplet
 
+
 class DropletFrame(DialogsMixin, wx.Frame, FrameReceiver):
 
     def __init__(self, actionlist, paths, *args, **keyw):
@@ -1076,13 +1089,7 @@ class DropletFrame(DialogsMixin, wx.Frame, FrameReceiver):
         self.Destroy()
 
 
-class DropletApp(wx.App):
-
-    def __init__(self, actionlist, paths, settings, *args, **keyw):
-        self.actionlist = actionlist
-        self.paths = paths
-        self._loadSettings(settings)
-        super(DropletApp, self).__init__(*args, **keyw)
+class DropletMixin:
 
     def OnInit(self):
         wx.InitAllImageHandlers()
@@ -1093,7 +1100,7 @@ class DropletApp(wx.App):
         #check for action list
         if self.actionlist == 'recent':
             self.actionlist = self.get_action_list(
-                self.get_action_list_files()+\
+                self.get_action_list_files() + \
                 self.settings['file_history'])
         if self.actionlist is None:
             return 0
@@ -1105,9 +1112,9 @@ class DropletApp(wx.App):
 
     def get_action_list_files(self):
         return glob.glob(os.path.join(ct.USER_ACTIONLISTS_PATH,
-                '*'+ct.EXTENSION)) +\
+                '*' + ct.EXTENSION)) +\
             glob.glob(os.path.join(config.PHATCH_ACTIONLISTS_PATH,
-                '*'+ct.EXTENSION))
+                '*' + ct.EXTENSION))
 
     def get_action_list(self, file_list):
         if not file_list:
@@ -1127,8 +1134,7 @@ class DropletApp(wx.App):
         return actionlist
 
     def init(self):
-        global api
-        from core import api
+        pass
 
     def _loadSettings(self, settings):
         self.settings = settings
@@ -1141,7 +1147,7 @@ class DropletApp(wx.App):
             except:
                 sys.stdout.write(' '.join([
                     _('Sorry, your settings seem corrupt.'),
-                    _('Please delete "%s".'%ct.USER_SETTINGS_PATH),
+                    _('Please delete "%s".' % ct.USER_SETTINGS_PATH),
                     _('Also check if your hard disk not full.\n')]))
                 sys.exit()
             f.close()
@@ -1161,18 +1167,28 @@ class DropletApp(wx.App):
         f.close()
 
 
+class DropletApp(DropletMixin, wx.App):
+
+    def __init__(self, actionlist, paths, settings, *args, **keyw):
+        self.actionlist = actionlist
+        self.paths = paths
+        self._loadSettings(settings)
+        super(DropletApp, self).__init__(*args, **keyw)
+
+
 def drop(actionlist, paths, settings):
     app = DropletApp(actionlist, paths, settings, 0)
     app.MainLoop()
 
 #---Application
 
-class App(DropletApp):
+
+class App(DropletMixin, wx.App):
 
     def __init__(self, settings, actionlist, *args, **keyw):
         self._loadSettings(settings)
         self.filename = actionlist
-        super(DropletApp, self).__init__(*args, **keyw)
+        super(App, self).__init__(*args, **keyw)
 
     def OnInit(self):
         wx.InitAllImageHandlers()
@@ -1185,11 +1201,16 @@ class App(DropletApp):
         wx.CallAfter(self.show_frame)
         return 1
 
+    def MacReopenApp(self):
+        """Called when the doc icon is clicked, and ???"""
+        #TODO: test if this is working
+        self.GetTopWindow().Raise()
+
     def _splash(self):
         return droplet.Frame(None,
-            title = ct.TITLE,
-            bitmap = graphics.bitmap(images.SPLASH),
-            splash = True,
+            title=ct.TITLE,
+            bitmap=graphics.bitmap(images.SPLASH),
+            splash=True,
         )
 
     def show_frame(self):
@@ -1211,8 +1232,6 @@ class App(DropletApp):
 
     def init(self):
         super(App, self).init()
-        global ICON_SIZE
-        from lib.pyWx.treeEdit import ICON_SIZE
 
     def _saveSettings(self):
         frame = self.GetTopWindow()
